Event JSON
{
"id": "3ffc7d84b9f30f810dfcee45601e10ee0f522ce5c1e345d0e1698eda082cabbd",
"pubkey": "5deba1e5cf488b37481efab30607c66bc56dec47b20a640c2f8d9d0d97e63f5e",
"created_at": 1791965842,
"kind": 1,
"tags": [
[
"t",
"avoyd"
],
[
"t",
"voxel"
],
[
"t",
"minecraft"
],
[
"t",
"VoxelEditor"
],
[
"t",
"pathtracing"
],
[
"t",
"raytracing"
],
[
"imeta",
"url https://cdn.masto.host/mastodongamedevplace/media_attachments/files/117/438/215/614/183/819/original/d7eb79b0a005efeb.jpg",
"m image/jpeg",
"dim 1920x1080",
"blurhash UdBW}cxtjFae?wxtj@bH%htQofj[tRogj[of"
],
[
"proxy",
"https://mastodon.gamedev.place/users/dougbinks/statuses/117438273462080269",
"activitypub"
],
[
"client",
"Mostr",
"31990:6be38f8c63df7dbf84db7ec4a6e6fbbd8d19dca3b980efad18585c46f04b26f9:mostr",
"wss://relay.ditto.pub"
]
],
"content": "Finally got around to moving the atmospheric shadow loop in Avoyd's GPU path tracer to a wavefront approach like the rest of the code instead of a loop. I was mainly doing this to improve the insane shader compilation times, but it also improves hardware utilization. Measuring compilation perf is tricky as the driver caches pipelines, but I've measured a consistent 2x render perf increase on top of a recent 3x perf increase.\n\n#Avoyd #Voxel #Minecraft #VoxelEditor #Pathtracing #Raytracing\n\nhttps://cdn.masto.host/mastodongamedevplace/media_attachments/files/117/438/215/614/183/819/original/d7eb79b0a005efeb.jpg",
"sig": "62ddf0104046bc1ea64d506dc7d3160f1f8dd7d25c563efda350313b37797df4f4fa8c8d96d932ff0f6696911e9711e128f668cd9fa65be3c1c67f7db0cf567e"
}